@@ -432,8 +432,8 @@ c transform back to original values
 *    Obtain eigenvalues and vectors and inverse of former *
 ***********************************************************
       implicit none
-      integer info,i,j
-      double precision rank
+      integer info,i,j, rank
+c      double precision rank
       integer m,pivot(m)
       double precision val(m),vec(m,m),invec(m,m),gamma(m,m),a(m),c(m),
      +     gmod(m,m),qraux(m),work(2*m),work3(m,m)
@@ -459,7 +459,7 @@ c invert matrix of eigenvectors
  2       continue
  1    continue
       call dqrdc2(gmod,m,m,m,1d-07,rank,qraux,pivot,work)
-      call dqrcf(gmod,m,rank,qraux,work3,m,invec,info,1)
+      call dqrcf(gmod,m,rank,qraux,work3,m,invec,info)
       return
       end
 
